/* --------------------------------------------------------------------------
  FILE        : spiboot.c                                                   
  PROJECT     : TI Booting and Flashing Utilities
  AUTHOR      : Daniel Allred
  DESC        : Module to boot the from a NAND flash device by finding the
                application (usually U-boot) and loading it to RAM.
----------------------------------------------------------------------------- */

#ifdef UBL_SPI

// General type include
#include "tistdtypes.h"

// Debug I/O module
#include "debug.h"

// Misc utility module
#include "util.h"

// Main UBL module
#include "ubl.h"

// SPI driver functions
#include "spi.h"
#include "spi_mem.h"

// This module's header file
#include "spiboot.h"

/************************************************************
* Explicit External Declarations                            *
************************************************************/

extern __FAR__ Uint32 DDRStart;
extern __FAR__ Uint32 DDRSize;

// Entrypoint for application we are decoding out of flash
extern Uint32 gEntryPoint;

/************************************************************
* Local Macro Declarations                                  *
************************************************************/


/************************************************************
* Local Typedef Declarations                                *
************************************************************/


/************************************************************
* Local Function Declarations                               *
************************************************************/


/************************************************************
* Local Variable Definitions                                *
************************************************************/


/************************************************************
* Global Variable Definitions                               *
************************************************************/

// structure for holding details about UBL stored in SPI
volatile SPIBOOT_HeaderObj  gSpiBoot;


/************************************************************
* Global Function Definitions                               *
************************************************************/

// Function to find out where the application is and copy to RAM
Uint32 SPIBOOT_copy()
{
  SPI_MemInfoHandle hSPIMemInfo;
  SPIBOOT_HeaderObj	header;

  DEBUG_printString("Starting SPI Copy...\r\n");
 
  hSPIMemInfo = SPI_MEM_open(0);

  if (hSPIMemInfo == NULL)
    return E_FAIL;
 
  // Assume U-Boot is at address 64K from start of SPI device (Block 0 has 
  // this UBL)
  SPI_MEM_readBytes(hSPIMemInfo, 32*1024, sizeof(header), (Uint8*) &header);

  SPI_MEM_readBytes(hSPIMemInfo, 32*1024 + sizeof(header), header.appSize, (Uint8*) header.ldAddress);

  gEntryPoint = header.entryPoint;

  // Since our entry point is set, just return success
  return E_PASS;
}

/************************************************************
* Local Function Definitions                                *
************************************************************/


/***********************************************************
* End file                                                 *
***********************************************************/
#endif  // #ifdef UBL_SPI
