/* --------------------------------------------------------------------------
  FILE        : spiboot.c                                                   
  PROJECT     : TI Booting and Flashing Utilities
  AUTHOR      : Daniel Allred
  DESC        : Module to boot the from a NAND flash device by finding the
                application (usually U-boot) and loading it to RAM.
----------------------------------------------------------------------------- */

#ifdef UBL_SPI

// General type include
#include "tistdtypes.h"

#include "device.h"

// Main UBL module
#include "ubl.h"

// SPI driver functions
#include "spi.h"
#include "spi_mem.h"

// This module's header file
#include "spiboot.h"

/************************************************************
* Explicit External Declarations                            *
************************************************************/

/************************************************************
* Local Macro Declarations                                  *
************************************************************/


/************************************************************
* Local Typedef Declarations                                *
************************************************************/


/************************************************************
* Local Function Declarations                               *
************************************************************/


/************************************************************
* Local Variable Definitions                                *
************************************************************/


/************************************************************
* Global Variable Definitions                               *
************************************************************/


/************************************************************
* Global Function Definitions                               *
************************************************************/

// Function to find out where the application is and copy to RAM
Uint32 SPIBOOT_copy()
{
  SPI_MemInfoHandle hSPIMemInfo;
 
  hSPIMemInfo = SPI_MEM_open(0);

  if (hSPIMemInfo == NULL)
    return E_FAIL;
 
  // Load ARM UBL into memory 
  SPI_MEM_readBytes(hSPIMemInfo, DEVICE_SPI_BOOT_ARM_UBL_OFFSET, DEVICE_SPI_BOOT_ARM_UBL_SIZE,
  				(Uint8*) DEVICE_ARM_UBL_LOAD_ADDR);

  // just return success
  return E_PASS;
}

/************************************************************
* Local Function Definitions                                *
************************************************************/


/***********************************************************
* End file                                                 *
***********************************************************/
#endif  // #ifdef UBL_SPI
